"""tasks3 is a commandline tool to create and manage tasks and todo lists"""

__author__ = """Harsh Parekh"""
__email__ = "harsh_parekh@outlook.com"
__version__ = "0.4.1"

from tasks3.tasks3 import add, edit, remove, search  # noqa: F401
